mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: linux@MichaelGeng.de (Michael Geng)
To: linux-kernel@vger.kernel.org
Cc: kraxel@bytesex.org
Subject: [PATCH] SAA5246A Teletext driver also works with SAA5281
Date: Tue, 6 Apr 2004 17:45:10 +0200	[thread overview]
Message-ID: <20040406154510.GA2075@t-online.de> (raw)

Hello,

the SAA5246A Teletext processor driver also works for the
SAA5281 (I am the author of this driver).

This is not surprising because according to the data sheet of 
the SAA5281 it is compatible to the SAA5246A. But now I have 
tested this with a Siemens Multimedia Extension Board (MXB).

The following patch only changes comments in 
/drivers/media/video/Kconfig and in the sources of the driver.

I also added MODULE_AUTHOR and MODULE_DESCRIPTION macros which
were missing up to now.

Michael

diff -u -N linux-2.6.5/drivers/media/video/Kconfig linux/drivers/media/video/Kconfig
--- linux-2.6.5/drivers/media/video/Kconfig	Sun Apr  4 05:38:16 2004
+++ linux/drivers/media/video/Kconfig	Mon Apr  5 21:25:31 2004
@@ -112,11 +112,11 @@
 	  It is also available as a module (cpia_usb).
 
 config VIDEO_SAA5246A
-	tristate "SAA5246A Teletext processor"
+	tristate "SAA5246A, SAA5281 Teletext processor"
 	depends on VIDEO_DEV && I2C
 	help
-	  Support for I2C bus based teletext using the SAA5246A chip. Useful
-	  only if you live in Europe.
+	  Support for I2C bus based teletext using the SAA5246A or SAA5281 
+	  chip. Useful only if you live in Europe.
 
 	  To compile this driver as a module, choose M here: the
 	  module will be called saa5246a.
Common subdirectories: linux-2.6.5/drivers/media/video/cx88 and linux/drivers/media/video/cx88
diff -u -N linux-2.6.5/drivers/media/video/saa5246a.h linux/drivers/media/video/saa5246a.h
--- linux-2.6.5/drivers/media/video/saa5246a.h	Sun Apr  4 05:37:39 2004
+++ linux/drivers/media/video/saa5246a.h	Mon Apr  5 21:20:30 2004
@@ -1,5 +1,7 @@
 /*
-   Driver for the SAA5246A videotext decoder chip from Philips.
+   Driver for the SAA5246A or SAA5281 Teletext (=Videotext) decoder chips from 
+   Philips.
+
    Copyright (C) 2004 Michael Geng (linux@MichaelGeng.de)
 
    This program is free software; you can redistribute it and/or modify
Common subdirectories: linux-2.6.5/drivers/media/video/saa7134 and linux/drivers/media/video/saa7134

                 reply	other threads:[~2004-04-06 15:47 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20040406154510.GA2075@t-online.de \
    --to=linux@michaelgeng.de \
    --cc=kraxel@bytesex.org \
    --cc=linux-kernel@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®
diff -u -N linux-2.6.5/drivers/media/video/saa5246a.c linux/drivers/media/video/saa5246a.c
--- linux-2.6.5/drivers/media/video/saa5246a.c	Sun Apr  4 05:36:58 2004
+++ linux/drivers/media/video/saa5246a.c	Mon Apr  5 21:20:40 2004
@@ -1,9 +1,10 @@
 /*
  * Driver for the SAA5246A videotext decoder chip from Philips.
  *
  * Only capturing of videotext pages is tested. The SAA5246A chip also has
  * a TV output but my hardware doesn't use it. For this reason this driver
  * does not support changing any TV display settings.
  *
  * Copyright (C) 2004 Michael Geng <linux@MichaelGeng.de>
  *
@@ -47,6 +48,10 @@
 #include <linux/videodev.h>
 #include "saa5246a.h"
 
+MODULE_AUTHOR("Michael Geng <linux@MichaelGeng.de>");
+MODULE_DESCRIPTION("Philips SAA5246A, SAA5281 Teletext decoder driver");
+MODULE_LICENSE("GPL");
+
 struct saa5246a_device
 {
 	u8     pgbuf[NUM_DAUS][VTX_VIRTUALSIZE];
@@ -764,8 +769,8 @@
 
 static int __init init_saa_5246a (void)
 {
-	printk(KERN_INFO "SAA5246A driver (" IF_NAME
-		" interface) for VideoText version %d.%d\n",
+	printk(KERN_INFO 
+		"SAA5246A (or compatible) Teletext decoder driver version %d.%d\n",
 		MAJOR_VERSION, MINOR_VERSION);
 	return i2c_add_driver(&i2c_driver_videotext);
 }
@@ -796,5 +801,3 @@
 	.release  = video_device_release,
 	.minor    = -1,
 };
-
-MODULE_LICENSE("GPL");
@@ -1,9 +1,10 @@
 /*
- * Driver for the SAA5246A videotext decoder chip from Philips.
+ * Driver for the SAA5246A or SAA5281 Teletext (=Videotext) decoder chips from 
+ * Philips.
  *
@@ -1,9 +1,10 @@
  *
- * Only capturing of videotext pages is tested. The SAA5246A chip also has
- * a TV output but my hardware doesn't use it. For this reason this driver
- * does not support changing any TV display settings.
+ * Only capturing of Teletext pages is tested. The chip also has a TV output 
+ * but my hardware doesn't use it. For this reason this driver does not support 
+ * changing any TV display settings.
  *
  * Copyright (C) 2004 Michael Geng <linux@MichaelGeng.de>